@@ -22,7 +22,7 @@ This set of classes represents cryptoPropertiesType Complex Type in the CycloneD
     Introduced in CycloneDX v1.6
 
 .. note::
-    See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.6/xml/#type_cryptoPropertiesType
+    See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.7/xml/#type_cryptoPropertiesType
 """
 
 from collections.abc import Iterable
@@ -35,7 +35,7 @@ from sortedcontainers import SortedSet
 
 from .._internal.compare import ComparableTuple as _ComparableTuple
 from ..exception.model import InvalidNistQuantumSecurityLevelException, InvalidRelatedCryptoMaterialSizeException
-from ..schema.schema import SchemaVersion1Dot6
+from ..schema.schema import SchemaVersion1Dot6, SchemaVersion1Dot7
 from .bom_ref import BomRef
 
 
@@ -48,7 +48,7 @@ class CryptoAssetType(str, Enum):
         Introduced in CycloneDX v1.6
 
     .. note::
-        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.6/xml/#type_cryptoPropertiesType
+        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.7/xml/#type_cryptoPropertiesType
     """
 
     ALGORITHM = 'algorithm'
@@ -67,7 +67,7 @@ class CryptoPrimitive(str, Enum):
         Introduced in CycloneDX v1.6
 
     .. note::
-        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.6/xml/#type_cryptoPropertiesType
+        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.7/xml/#type_cryptoPropertiesType
     """
 
     AE = 'ae'
@@ -98,7 +98,7 @@ class CryptoExecutionEnvironment(str, Enum):
         Introduced in CycloneDX v1.6
 
     .. note::
-        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.6/xml/#type_cryptoPropertiesType
+        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.7/xml/#type_cryptoPropertiesType
     """
 
     HARDWARE = 'hardware'
@@ -120,7 +120,7 @@ class CryptoImplementationPlatform(str, Enum):
         Introduced in CycloneDX v1.6
 
     .. note::
-        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.6/xml/#type_cryptoPropertiesType
+        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.7/xml/#type_cryptoPropertiesType
     """
 
     ARMV7_A = 'armv7-a'
@@ -150,7 +150,7 @@ class CryptoCertificationLevel(str, Enum):
         Introduced in CycloneDX v1.6
 
     .. note::
-        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.6/xml/#type_cryptoPropertiesType
+        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.7/xml/#type_cryptoPropertiesType
     """
 
     NONE = 'none'
@@ -196,7 +196,7 @@ class CryptoMode(str, Enum):
         Introduced in CycloneDX v1.6
 
     .. note::
-        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.6/xml/#type_cryptoPropertiesType
+        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.7/xml/#type_cryptoPropertiesType
     """
 
     CBC = 'cbc'
@@ -221,7 +221,7 @@ class CryptoPadding(str, Enum):
         Introduced in CycloneDX v1.6
 
     .. note::
-        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.6/xml/#type_cryptoPropertiesType
+        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.7/xml/#type_cryptoPropertiesType
     """
 
     PKCS5 = 'pkcs5'
@@ -244,7 +244,7 @@ class CryptoFunction(str, Enum):
         Introduced in CycloneDX v1.6
 
     .. note::
-        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.6/xml/#type_cryptoPropertiesType
+        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.7/xml/#type_cryptoPropertiesType
     """
 
     DECAPSULATE = 'decapsulate'
@@ -273,7 +273,7 @@ class AlgorithmProperties:
         Introduced in CycloneDX v1.6
 
     .. note::
-        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.6/xml/#type_cryptoPropertiesType
+        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.7/xml/#type_cryptoPropertiesType
     """
 
     def __init__(
@@ -394,6 +394,7 @@ class AlgorithmProperties:
     @property
     @serializable.json_name('certificationLevel')
     @serializable.view(SchemaVersion1Dot6)
+    @serializable.view(SchemaVersion1Dot7)
     @serializable.xml_array(serializable.XmlArraySerializationType.FLAT, child_name='certificationLevel')
     @serializable.xml_sequence(5)
     def certification_levels(self) -> 'SortedSet[CryptoCertificationLevel]':
@@ -507,6 +508,11 @@ class AlgorithmProperties:
             return self.__comparable_tuple() == other.__comparable_tuple()
         return False
 
+    def __lt__(self, other: object) -> bool:
+        if isinstance(other, AlgorithmProperties):
+            return self.__comparable_tuple() < other.__comparable_tuple()
+        return NotImplemented
+
     def __hash__(self) -> int:
         return hash(self.__comparable_tuple())
 
@@ -525,7 +531,7 @@ class CertificateProperties:
 
 
     .. note::
-        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.6/xml/#type_cryptoPropertiesType
+        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.7/xml/#type_cryptoPropertiesType
     """
 
     def __init__(
@@ -683,6 +689,11 @@ class CertificateProperties:
             return self.__comparable_tuple() == other.__comparable_tuple()
         return False
 
+    def __lt__(self, other: object) -> bool:
+        if isinstance(other, CertificateProperties):
+            return self.__comparable_tuple() < other.__comparable_tuple()
+        return NotImplemented
+
     def __hash__(self) -> int:
         return hash(self.__comparable_tuple())
 
@@ -700,7 +711,7 @@ class RelatedCryptoMaterialType(str, Enum):
         Introduced in CycloneDX v1.6
 
     .. note::
-        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.6/xml/#type_cryptoPropertiesType
+        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.7/xml/#type_cryptoPropertiesType
     """
 
     ADDITIONAL_DATA = 'additional-data'
@@ -735,7 +746,7 @@ class RelatedCryptoMaterialState(str, Enum):
         Introduced in CycloneDX v1.6
 
     .. note::
-        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.6/xml/#type_cryptoPropertiesType
+        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.7/xml/#type_cryptoPropertiesType
     """
 
     ACTIVE = 'active'
@@ -757,7 +768,7 @@ class RelatedCryptoMaterialSecuredBy:
 
 
     .. note::
-        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.6/xml/#type_cryptoPropertiesType
+        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.7/xml/#type_cryptoPropertiesType
     """
 
     def __init__(
@@ -810,6 +821,11 @@ class RelatedCryptoMaterialSecuredBy:
             return self.__comparable_tuple() == other.__comparable_tuple()
         return False
 
+    def __lt__(self, other: object) -> bool:
+        if isinstance(other, RelatedCryptoMaterialSecuredBy):
+            return self.__comparable_tuple() < other.__comparable_tuple()
+        return NotImplemented
+
     def __hash__(self) -> int:
         return hash(self.__comparable_tuple())
 
@@ -828,7 +844,7 @@ class RelatedCryptoMaterialProperties:
 
 
     .. note::
-        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.6/xml/#type_cryptoPropertiesType
+        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.7/xml/#type_cryptoPropertiesType
     """
 
     def __init__(
@@ -1055,6 +1071,11 @@ class RelatedCryptoMaterialProperties:
             return self.__comparable_tuple() == other.__comparable_tuple()
         return False
 
+    def __lt__(self, other: object) -> bool:
+        if isinstance(other, RelatedCryptoMaterialProperties):
+            return self.__comparable_tuple() < other.__comparable_tuple()
+        return NotImplemented
+
     def __hash__(self) -> int:
         return hash(self.__comparable_tuple())
 
@@ -1072,7 +1093,7 @@ class ProtocolPropertiesType(str, Enum):
         Introduced in CycloneDX v1.6
 
     .. note::
-        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.6/xml/#type_cryptoPropertiesType
+        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.7/xml/#type_cryptoPropertiesType
     """
 
     IKE = 'ike'
@@ -1097,7 +1118,7 @@ class ProtocolPropertiesCipherSuite:
 
 
     .. note::
-        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.6/xml/#type_cryptoPropertiesType
+        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.7/xml/#type_cryptoPropertiesType
     """
 
     def __init__(
@@ -1190,7 +1211,7 @@ class Ikev2TransformTypes:
 
 
     .. note::
-        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.6/xml/#type_cryptoPropertiesType
+        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.7/xml/#type_cryptoPropertiesType
     """
 
     def __init__(
@@ -1314,6 +1335,11 @@ class Ikev2TransformTypes:
             return self.__comparable_tuple() == other.__comparable_tuple()
         return False
 
+    def __lt__(self, other: object) -> bool:
+        if isinstance(other, Ikev2TransformTypes):
+            return self.__comparable_tuple() < other.__comparable_tuple()
+        return NotImplemented
+
     def __hash__(self) -> int:
         return hash(self.__comparable_tuple())
 
@@ -1332,7 +1358,7 @@ class ProtocolProperties:
 
 
     .. note::
-        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.6/xml/#type_cryptoPropertiesType
+        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.7/xml/#type_cryptoPropertiesType
     """
 
     def __init__(
@@ -1440,6 +1466,11 @@ class ProtocolProperties:
             return self.__comparable_tuple() == other.__comparable_tuple()
         return False
 
+    def __lt__(self, other: object) -> bool:
+        if isinstance(other, ProtocolProperties):
+            return self.__comparable_tuple() < other.__comparable_tuple()
+        return NotImplemented
+
     def __hash__(self) -> int:
         return hash(self.__comparable_tuple())
 
@@ -1457,7 +1488,7 @@ class CryptoProperties:
 
 
     .. note::
-        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.6/xml/#type_cryptoPropertiesType
+        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.7/xml/#type_cryptoPropertiesType
     """
 
     def __init__(
