@@ -30,7 +30,7 @@ from cyclonedx.model.contact import OrganizationalContact, OrganizationalEntity
 from cyclonedx.model.license import DisjunctiveLicense
 from cyclonedx.model.lifecycle import LifecyclePhase, NamedLifecycle, PredefinedLifecycle
 from cyclonedx.model.tool import Tool
-from cyclonedx.output.json import JsonV1Dot6
+from cyclonedx.output.json import JsonV1Dot7
 from tests._data.models import (
     get_bom_component_licenses_invalid,
     get_bom_component_nested_licenses_invalid,
@@ -107,6 +107,26 @@ class TestBomMetaData(TestCase):
         self.assertTrue(tools[0] in metadata.tools.tools)
         self.assertTrue(tools[1] in metadata.tools.tools)
 
+    def test_bom_metadata_sorting(self) -> None:
+        """Test that BomMetaData instances can be sorted without triggering TypeError"""
+        metadata1 = BomMetaData(
+            tools=[Tool(name='tool_a')],
+            authors=[OrganizationalContact(name='contact_a')]
+        )
+        metadata2 = BomMetaData(
+            tools=[Tool(name='tool_b')],
+            authors=[OrganizationalContact(name='contact_b')]
+        )
+        metadata3 = BomMetaData(
+            tools=[Tool(name='tool_c')],
+            authors=[OrganizationalContact(name='contact_c')]
+        )
+
+        # This should not raise TypeError: '<' not supported between instances
+        metadata_list = [metadata3, metadata1, metadata2]
+        sorted_metadata = sorted(metadata_list)
+        self.assertEqual(len(sorted_metadata), 3)
+
 
 @ddt
 class TestBom(TestCase):
@@ -143,14 +163,14 @@ class TestBom(TestCase):
         with warnings.catch_warnings(record=True) as w:
             warnings.simplefilter('always')
             bom = Bom(metadata=BomMetaData(component=Component(name='test', version='1.2')))
-            _ = JsonV1Dot6(bom).output_as_string()
+            _ = JsonV1Dot7(bom).output_as_string()
             self.assertEqual(len(w), 0)
 
     def test_warning_missing_dependency(self) -> None:
         with self.assertWarns(expected_warning=UserWarning) as w:
             bom = Bom(metadata=BomMetaData(component=Component(name='root_component', version='1.2')))
             bom.components.add(Component(name='test2', version='4.2'))
-            _ = JsonV1Dot6(bom).output_as_string()
+            _ = JsonV1Dot7(bom).output_as_string()
             self.assertEqual(len(w.warnings), 1)
             self.assertIn('has no defined dependencies ', str(w.warnings[0]))
 
